@@ -5,7 +5,7 @@ use warnings;
 use Carp();
 use overload '""' => 'string';
 
-our $VERSION = '1.00_03';
+our $VERSION = '1.08_01';
 
 sub throw {
     my ( $class, $string ) = @_;
@@ -27,7 +27,7 @@ sub _throw {
 
 sub string {
     my ($self) = @_;
-    return "$self->{string} in $self->{origin} at line $self->{line}\n";
+    return $self->{string};
 }
 
 1;    # Magic true value required at end of module
@@ -39,7 +39,7 @@ Firefox::Marionette::Exception - Represents an base exception class for exceptio
 
 =head1 VERSION
 
-Version 1.00_03
+Version 1.08_01
 
 =head1 SYNOPSIS
 
